@@ -93,7 +93,11 @@ def main():
         pdf.cell(w=50, h=10, txt=project_name.upper(), align='R', ln=2)
         pdf.set_font('Arial', size=14)
         pdf.cell(w=50, h=10, txt=camname, align='R')
-        pdf.image(logo, x=9, y=190, w=65, link="https://www.animotions.be")
+        pdf.image(str(logo),
+                  x=9,
+                  y=188,
+                  w=65,
+                  link="https://www.animotions.be")
         pdf.set_fill_color(200, 200, 200)
         pdf.rect(x=80, y=15, w=frame_width, h=frame_height, style='F')
         width, height = imagesize.get(str(f))
